<?php

require_once 'MysqlConnector.php';

class GerenciadorUsuarios {
    private $db;

    public function __construct() {
        // Inicializa uma nova conexão com o banco de dados
        $this->db = new MysqlConnector();
    }

    public function buscarUsuario($idusuario = 0) {
        // Prepare a consulta SQL com um marcador de posição para o parâmetro
        $sql = "SELECT s.*, IF(s.idgrupo IS NULL,'Sem Grupo',g.descricao) AS Descricao FROM supadmin s LEFT JOIN grupo g ON g.IdGrupo = s.idgrupo WHERE s.deletado = 'Não' AND (0 = ? OR s.Id = ?)";

        $link = $this->db->GetConnectionLink();

        // Prepare a declaração SQL
        $stmt = $link->prepare($sql);

        // Vincule o parâmetro à declaração
        $stmt->bind_param("ii", $idusuario, $idusuario);

        // Execute a consulta
        $stmt->execute();

        // Obtenha os resultados da consulta
        $result = $stmt->get_result();

        // Verifique se houve erros na consulta
        if (!$result) {
            // Lançar uma exceção em vez de apenas imprimir uma mensagem
            throw new Exception("Erro na consulta: " . $link->error);
        }

        // Fetch os dados
        $dados = $result->fetch_all(MYSQLI_ASSOC);

        // Feche a declaração
        $stmt->close();

        return $dados;
    }

    public function inserirUsuario($nome, $email,$idgrupo) {
        $sql = "INSERT INTO supadmin (Nome, Email, Senha, IdGrupo) VALUES (?, ?, md5(123),?)";

        $link = $this->db->GetConnectionLink();

        // Prepare a declaração SQL
        $stmt = $link->prepare($sql);

        // Vincule os parâmetros à declaração
        $stmt->bind_param("ssi", $nome, $email,$idgrupo);

        // Execute a declaração
        $result = $stmt->execute();

        // Verifique se houve erros na execução
        if (!$result) {
            // Lançar uma exceção em vez de apenas imprimir uma mensagem
            throw new Exception("Erro ao inserir usuário: " . $link->error);
        }

        // Feche a declaração
        $stmt->close();

        return $result;
    }

    public function editarUsuario($idusuario, $nome, $email,$idgrupo) {
        $sql = "UPDATE supadmin SET Nome = ?, Email = ?, IdGrupo = ? WHERE Id = ?";

        $link = $this->db->GetConnectionLink();

        // Prepare a declaração SQL
        $stmt = $link->prepare($sql);

        // Vincule os parâmetros à declaração
        $stmt->bind_param("ssii", $nome, $email,$idgrupo, $idusuario);

        // Execute a declaração
        $result = $stmt->execute();

        // Verifique se houve erros na execução
        if (!$result) {
            // Lançar uma exceção em vez de apenas imprimir uma mensagem
            throw new Exception("Erro ao editar usuário: " . $link->error);
        }

        // Feche a declaração
        $stmt->close();

        return $result;
    }

    public function deletarUsuario($idusuario) {
        $sql = "DELETE FROM supadmin WHERE Id = ?";

        $link = $this->db->GetConnectionLink();

        // Prepare a declaração SQL
        $stmt = $link->prepare($sql);

        // Vincule o parâmetro à declaração
        $stmt->bind_param("i", $idusuario);

        // Execute a declaração
        $result = $stmt->execute();

        // Verifique se houve erros na execução
        if (!$result) {
            // Lançar uma exceção em vez de apenas imprimir uma mensagem
            throw new Exception("Erro ao deletar usuário: " . $link->error);
        }

        // Feche a declaração
        $stmt->close();

        return $result;
    }

    public function resetarSenha($idusuario) {
      $sql = "UPDATE supadmin SET SENHA = md5(123) WHERE Id = ?";

      $link = $this->db->GetConnectionLink();

      // Prepare a declaração SQL
      $stmt = $link->prepare($sql);

      // Vincule o parâmetro à declaração
      $stmt->bind_param("i", $idusuario);

      // Execute a declaração
      $result = $stmt->execute();

      // Verifique se houve erros na execução
      if (!$result) {
          // Lançar uma exceção em vez de apenas imprimir uma mensagem
          throw new Exception("Erro ao resetar senha do usuário: " . $link->error);
      }

      // Feche a declaração
      $stmt->close();

      return $result;
  }
}

?>
